//---------------------------------------------------------------------------
//--
//-- Title : spi1248_cont
//-- Author : A.J. Dougan
//-- Company : Future Technology Devices International Ltd.
//--
//---------------------------------------------------------------------------
//-- Purpose
//--          This program will control the Morphic code for spi1248 control
//--          called MorphIC_HS_spi1248.
//--
//---------------------------------------------------------------------------
//-- Ver 1.1
//-- Date : loopback Nov 2010
//--
//-- Created
//--
//---------------------------------------------------------------------------
//-- Ver 1.0
//-- Date : 30th April 2010
//--
//-- Created
//--
//---------------------------------------------------------------------------
//---------------------------------------------------------------------------
// Copyright Future Technology Devices International Ltd 2010
//---------------------------------------------------------------------------
//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop
#include <time.h>
#include <dir.h>
#include <stdio.h>

#include "Unit1.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TForm1 *Form1;
//---------------------------------------------------------------------------
__fastcall TForm1::TForm1(TComponent* Owner)
	: TForm(Owner)
{
}
//---------------------------------------------------------------------------
// variables
//---------------------------------------------------------------------------
// Version string

const char version[] = "1.2";

//---------------------------------------------------------------------------
typedef char devname[81];
devname DevNames[21];
bool PortOpen;
byte FT_Read_Buffer[0x10000];
byte FT_Write_Buffer[0x10000];
byte Read_Buffer[0x10000];
byte Write_Buffer[0x10000];
int WriteBuffCnt;

const int timeout_secs = 20;

enum spicmd {CMD_WRITE=0,CMD_READ=1,CMD_RD_MDM=2,CMD_WR_MDM=3,CMD_FLUSH=4,
			 CMD_SETUP=5};

FT_HANDLE ftHandle;
int modem_ctrl;
int setup_ctrl;  // bit 4 = CPOL 3 downto 0 = width

byte data_byte;

long int global_data_size_megabytes;
long int global_data_size_bytes;
bool show_megabytes = false;

bool receiving_file;
//---------------------------------------------------------------------------
//---------------------------------------------------------------------------

void ShowMsg(char *msgstr)
{
Form1->Memo1->Lines->Add(msgstr);
}
//---------------------------------------------------------------------------
void List_Devs()
{
		FT_HANDLE ftHandle;
		FT_STATUS ftStatus;
		int No_Of_Devs = 0;
		char msgStr[80];
		long DevNum = 0;
		int j = 0;

	ftStatus = FT_ListDevices(&No_Of_Devs,0,FT_LIST_NUMBER_ONLY);
	if((ftStatus==FT_OK)&&(No_Of_Devs>0)){
	  for(int i=0;i<No_Of_Devs;i++){
		msgStr[0]=0;
		ftStatus = FT_ListDevices((PVOID)DevNum,&msgStr,(FT_LIST_BY_INDEX|FT_OPEN_BY_DESCRIPTION));
		if((ftStatus==FT_OK)&&(msgStr[0]!=0)){
		  strcpy(DevNames[j],msgStr);
		  j++;
		  }
		++DevNum;
		}
	  }
}
//---------------------------------------------------------------------------
bool openport(char *devname,FT_HANDLE *ftHandle,bool &PortOpen)
{
  FT_STATUS ftStatus;
  FT_HANDLE LocHandle = 0;

  ftStatus = FT_OpenEx(devname,FT_OPEN_BY_DESCRIPTION,ftHandle);
  if(ftStatus==FT_OK){
	PortOpen = true;
	return true;
	}
  else{
	PortOpen = false;
	return false;
	}
}
//---------------------------------------------------------------------------
bool closeport(FT_HANDLE ftHandle)
{
  FT_STATUS ftStatus;

  ftStatus = FT_Close(ftHandle);
  if(ftStatus==FT_OK){
	return true;
	}
  else{
	return false;
	}
}
//---------------------------------------------------------------------------
bool setup_port(FT_HANDLE ftHandle,bool use_sync245)
  {
  bool passed = true;
  FT_STATUS ft_res;
  ULONG baudrate;
  char msgstr[80];

  //
  // set baudrate
  //
//  baudrate = StrToInt(Form1->Edit1->Text);
//  ft_res =  FT_SetBaudRate(ftHandle,baudrate);
//  if(ft_res != FT_OK) passed = false;
  //
  // purge port
  //
  ft_res =  FT_Purge(ftHandle,(ULONG)FT_PURGE_RX | FT_PURGE_TX);
  if(ft_res != FT_OK) passed = false;
  //
  // set sync bitbang
  //
  if(use_sync245)
	{
	//
	// set handshaking to control driver
	//
	ft_res =  FT_SetFlowControl(ftHandle,FT_FLOW_RTS_CTS,0,0);
	if(ft_res != FT_OK) passed = false;

	ft_res = FT_SetBitMode(ftHandle,0xFF,0x40);
	if(ft_res != FT_OK) passed = false;
	}
  else
	{
	ft_res = FT_SetBitMode(ftHandle,0x00,0);
	if(ft_res != FT_OK){
	  strcpy(msgstr,"Failed SetBitMode Command - continuing");
	  ShowMsg(msgstr);
	}
	//
	// set handshaking for RS232
	//
	ft_res =  FT_SetFlowControl(ftHandle,FT_FLOW_RTS_CTS,0,0);
	if(ft_res != FT_OK) passed = false;
	//
	// set RTS
	//
	ft_res = FT_SetRts(ftHandle);
	if(ft_res != FT_OK) passed = false;
	//
	// set data chars
	//
	ft_res =  FT_SetDataCharacteristics(ftHandle,8,1,0);
	if(ft_res != FT_OK) passed = false;
	}


  return passed;
  }
//---------------------------------------------------------------------------
void AddToBuffer(char chr)
{
  Write_Buffer[WriteBuffCnt] = chr;
  WriteBuffCnt++;
}
//---------------------------------------------------------------------------
bool SendData(FT_HANDLE ftHandle)
{
  bool passed = true;
  FT_STATUS ft_res;
  ULONG numberwritten;
  char msgstr[80];

  if(PortOpen) {
	ft_res = FT_Write(ftHandle,Write_Buffer,WriteBuffCnt,&numberwritten);
	WriteBuffCnt -= numberwritten;
	if(ft_res!= FT_OK) passed = false;
  }
  else {
	strcpy(msgstr,"Error : Port is closed");
	ShowMsg(msgstr);
  }

  return passed;
}
//---------------------------------------------------------------------------
int ReadData(FT_HANDLE ftHandle,int numbertoread)
{
  FT_STATUS ft_res;
  int TotalRead = 0;
  ULONG no_bytes = 0;
  bool finished = false;
  ULONG i;
  int readpointer = 0;
  time_t timestart;
  time_t timenow;
  char msgstr[80];

  timestart = time(0);

  while(!finished)
	{
	ft_res = FT_GetQueueStatus(ftHandle,&no_bytes);
	if(no_bytes) // read from driver
	  {
	  if((TotalRead + no_bytes) > numbertoread)
		{
		no_bytes = numbertoread - TotalRead;
		}
	  ft_res = FT_Read(ftHandle,FT_Read_Buffer,no_bytes,&no_bytes);
	  for(int i=0;i<no_bytes;i++) // copy data to user buffer
		{
		Read_Buffer[readpointer] = FT_Read_Buffer[i];
		readpointer++;
		}
	  TotalRead += no_bytes;
	  }
	timenow = time(0);

	if(TotalRead==numbertoread)
	  {
	   finished = true;
	  }
	else if (ft_res != FT_OK)
	  {
	   strcpy(msgstr,"Error : FT_Res return code not Ok. Got : ");
//       strcat(msgstr,IntToStr(ft_res).t_str());
	   finished = true;
	  }
	else if((timenow - timestart) > timeout_secs)
	  {
	   strcpy(msgstr,"Error : Timed out");
	   finished = true;
	  }
	else
	   Sleep(0);
	}
	return TotalRead;

}
//---------------------------------------------------------------------------
void GetNames(void)
{

  // clear combo box
  Form1->ComboBox1->Clear();

  // clear devnames array
  for(int i=0;i<21;i++){
	DevNames[i][0] = 0;
	}
  List_Devs();
  for(int i=0;i<21;i++){
	if(DevNames[i][0]!=0){
	  Form1->ComboBox1->Items->Add(DevNames[i]);
	  }
	}
}
//---------------------------------------------------------------------------
void __fastcall TForm1::ComboBox1DropDown(TObject *Sender)
{
  GetNames();
}
//---------------------------------------------------------------------------
void set_mdm_stat(int data){

  if ((data & 0x01) != 0)  //DTR
	Form1->CheckBox6->Checked = true;
  else
	Form1->CheckBox6->Checked = false;

  if ((data & 0x02) != 0)  //RTS
	Form1->CheckBox5->Checked = true;
  else
	Form1->CheckBox5->Checked = false;

}

//---------------------------------------------------------------------------
bool send_command(spicmd cmd)
{
  char msgstr[80];
  bool passed = true;
  byte tmpbyte;
  int i;

  if (PortOpen) {
	switch(cmd) {
	  case CMD_WRITE : {
		AddToBuffer(0x00);
		AddToBuffer(0x00);
		AddToBuffer(0x00);
		AddToBuffer(data_byte);
		passed = SendData(ftHandle);

		break;
		}
	  case CMD_READ : { // not required as this is default

		break;
		}
	  case CMD_RD_MDM : {
		AddToBuffer(0x02);
		passed = SendData(ftHandle);
		i = ReadData(ftHandle,1);
		strcpy(msgstr,"Sending Read Modem Status Command");
		if (i==1) {
		  tmpbyte = Read_Buffer[0];
		  set_mdm_stat(tmpbyte);
		  }
		break;
		}
	  case CMD_WR_MDM : {
		AddToBuffer(0x03);
		AddToBuffer(modem_ctrl&0xFF);
		passed = SendData(ftHandle);
		strcpy(msgstr,"Sending Write Modem Status Command ");
		strcat(msgstr,IntToHex(modem_ctrl,2).t_str());
		ShowMsg(msgstr);
		break;
		}
	  case CMD_FLUSH : {

		break;
		}
	  case CMD_SETUP : {
		AddToBuffer(0x05);
		AddToBuffer(setup_ctrl&0xFF);
		passed = SendData(ftHandle);
		strcpy(msgstr,"Sending Setup Command ");
		strcat(msgstr,IntToHex(setup_ctrl,2).t_str());
		ShowMsg(msgstr);
		break;
		}
	  default : {
		strcpy(msgstr,"Error : Unknown cmd ");
		ShowMsg(msgstr);
		passed = false;
	  }
	}


  }
  return passed;
}
//---------------------------------------------------------------------------
void disable_buttons(void){
  Form1->Button1->Enabled = false;
}
//---------------------------------------------------------------------------
void enable_buttons(void){
  Form1->Button1->Enabled = true;
}
//---------------------------------------------------------------------------
void disable_features(void){
  Form1->CheckBox1->Enabled=false;
  Form1->CheckBox2->Enabled=false;
  Form1->CheckBox3->Enabled=false;
  Form1->CheckBox4->Enabled=false;
  Form1->Button2->Enabled=false;
  Form1->Button3->Enabled=false;
  Form1->Button5->Enabled=false;
}
//---------------------------------------------------------------------------
void enable_features(void){
  Form1->CheckBox1->Enabled=true;
  Form1->CheckBox2->Enabled=true;
  Form1->CheckBox3->Enabled=true;
  Form1->CheckBox4->Enabled=true;
  Form1->Button2->Enabled=true;
  Form1->Button3->Enabled=true;
  Form1->Button5->Enabled=true;
}
//---------------------------------------------------------------------------
bool do_loopback(ULONG no_of_bytes){

  ULONG numberwritten;
  bool passed = true;
  FT_STATUS ft_res;
  char my_string[40];

  AddToBuffer(0x00);
  AddToBuffer((no_of_bytes-1) & 0xFF);
  AddToBuffer(((no_of_bytes-1)>> 8) & 0xFF);
  passed = SendData(ftHandle);

  ft_res = FT_Write(ftHandle,Read_Buffer,no_of_bytes,&numberwritten);

  global_data_size_bytes += no_of_bytes;
  if (global_data_size_bytes > 1000000){
	global_data_size_bytes -= 1000000;
	global_data_size_megabytes += 1;}

  int i = sprintf(my_string,"%d.%06d MBytes",global_data_size_megabytes,global_data_size_bytes);
  Form1->Edit1->Text = my_string;

  /*
  if (global_data_size_bytes > 1048576){
	global_data_size_bytes -= 1048576;
	global_data_size_megabytes += 1;
	show_megabytes = true;
	}
  if (show_megabytes) {
	int i = sprintf(my_string,"%d MBytes",global_data_size_megabytes);
	Form1->Edit1->Text = my_string;
	}
  else {
	int i = sprintf(my_string,"%d",global_data_size_bytes);
	Form1->Edit1->Text = my_string;
	}
*/

  if(ft_res!= FT_OK) passed = false;
  return passed;
}
//---------------------------------------------------------------------------
void check_for_data(void){
  FT_STATUS ft_res;
  ULONG no_bytes;
  int i;

  ft_res = FT_GetQueueStatus(ftHandle,&no_bytes);
  if (no_bytes) {
	Form1->Timer1->Enabled = false;
	i = ReadData(ftHandle,no_bytes);
	Read_Buffer[i]=0;
	if (Form1->CheckBox7->Checked) {
	  do_loopback(i);
	}
	else {
	  ShowMsg(Read_Buffer);
	}
//	send_command(CMD_RD_MDM);
	Form1->Timer1->Enabled = true;
	}
  else{
//	send_command(CMD_RD_MDM);
	Sleep(0);
	}

  }

//---------------------------------------------------------------------------
void set_mdm_ctrl_byte(void){
  modem_ctrl =0;
  if (Form1->CheckBox1->Checked) modem_ctrl |= 0x10;
  if (Form1->CheckBox2->Checked) modem_ctrl |= 0x20;
  if (Form1->CheckBox3->Checked) modem_ctrl |= 0x40;
  if (Form1->CheckBox4->Checked) modem_ctrl |= 0x80;
}
//---------------------------------------------------------------------------
void set_setup_ctrl_byte(void){
  setup_ctrl =0;
  if (Form1->RadioButton3->Checked) setup_ctrl = 0x01;
  if (Form1->RadioButton4->Checked) setup_ctrl = 0x02;
  if (Form1->RadioButton5->Checked) setup_ctrl = 0x04;
  if (Form1->RadioButton6->Checked) setup_ctrl = 0x08;
  if (Form1->RadioButton2->Checked) setup_ctrl |= 0x10;
  if (Form1->RadioButton8->Checked) setup_ctrl |= 0x20;
  if (Form1->RadioButton10->Checked) setup_ctrl |= 0x40;
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Button1Click(TObject *Sender)
{
  char msgstr[80];
  bool passed;
  char devn[81];

  disable_buttons();

if (Form1->Button1->Caption=="Open") {
  if (Form1->ComboBox1->Text!="") {
	strcpy(devn,Form1->ComboBox1->Text.t_str());
	if(openport(devn,&ftHandle,PortOpen))
	  {
	  strcpy(msgstr,"Opened Port : ");
	  strcat(msgstr,devn);
	  ShowMsg(msgstr);
	  Form1->Button1->Caption="Close";
	  set_setup_ctrl_byte();
	  passed = send_command(CMD_SETUP);
	  enable_features();
	  Form1->Timer1->Enabled = true;
	  }
	else
	  {
	  strcpy(msgstr,"Error : opening port");
	  strcat(msgstr,devn);
	  ShowMsg(msgstr);
	  }
	}
  else{
	strcpy(msgstr,"Error : you must select a device");
	ShowMsg(msgstr);
	}
  }
else {
  Form1->Button1->Caption="Open";
  passed = closeport(ftHandle);
  if (passed) strcpy(msgstr,"Port Closed");
  else strcpy(msgstr,"Error Closing Port");
  ShowMsg(msgstr);
  disable_features();
  Form1->Timer1->Enabled = false;
  }

  enable_buttons();

}
//---------------------------------------------------------------------------
void __fastcall TForm1::FormCreate(TObject *Sender)
{
char title[80];

strcpy(title,"FT1248 Controller : ");
strcat(title,version);
Form1->Caption = title;
disable_features();
set_mdm_ctrl_byte();

}
//---------------------------------------------------------------------------
void __fastcall TForm1::CheckBox1Click(TObject *Sender)
{
  bool passed;

  set_mdm_ctrl_byte();
  passed = send_command(CMD_WR_MDM);

}
//---------------------------------------------------------------------------
void __fastcall TForm1::CheckBox2Click(TObject *Sender)
{
  bool passed;

  set_mdm_ctrl_byte();
  passed = send_command(CMD_WR_MDM);

}
//---------------------------------------------------------------------------
void __fastcall TForm1::CheckBox3Click(TObject *Sender)
{
  bool passed;

  set_mdm_ctrl_byte();
  passed = send_command(CMD_WR_MDM);

}
//---------------------------------------------------------------------------
void __fastcall TForm1::CheckBox4Click(TObject *Sender)
{
  bool passed;

  set_mdm_ctrl_byte();
  passed = send_command(CMD_WR_MDM);

}
//---------------------------------------------------------------------------
void __fastcall TForm1::RadioButton1Click(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::RadioButton2Clck(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::RadioButton3Click(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::RadioButton4Click(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::RadioButton5Click(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::RadioButton6Click(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Timer1Timer(TObject *Sender)
{
check_for_data();
}
//---------------------------------------------------------------------------
void __fastcall TForm1::Memo1KeyPress(TObject *Sender, wchar_t &Key)
{

  bool passed;

  data_byte = (byte)Key;
  passed = send_command(CMD_WRITE);


}
//---------------------------------------------------------------------------
void save_file(char filename[256]){
  int  iFileHandle=0;
  char MyMsg[300];
  int  iBytesRead = 1;
  FT_STATUS ft_res;
  ULONG no_bytes;
  int i;


  iFileHandle = FileCreate(filename);
  if (!iFileHandle)
	{
	strcpy(MyMsg,"ERROR: Opening file");
	strcat(MyMsg,filename);
	ShowMsg(MyMsg);
	}
  else
	{
	strcpy(MyMsg,"Opened File: ");
	strcat(MyMsg,filename);
	ShowMsg(MyMsg);
	// read and store received data
	while (receiving_file) {
	  ft_res = FT_GetQueueStatus(ftHandle,&no_bytes);
	  if (no_bytes) {
		Form1->Timer1->Enabled = false;
		i = ReadData(ftHandle,no_bytes);
		FileWrite(iFileHandle,Read_Buffer,i);
		}
	  else{
		Sleep(0);
		}
	  Application->ProcessMessages();
	  }

	// done
	FileClose(iFileHandle);
	strcpy(MyMsg,"Closed File: ");
	strcat(MyMsg,filename);
	ShowMsg(MyMsg);
	}

}
//---------------------------------------------------------------------------
void send_file(char filename[256]){

  int  iFileHandle=0;
  char MyMsg[300];
  int  iBytesRead = 1;
  bool passed = true;
  FT_STATUS ft_res;
  ULONG numberwritten;


  iFileHandle = FileOpen(filename, fmOpenRead);
  if (!iFileHandle)
	{
	strcpy(MyMsg,"ERROR: Opening file");
	ShowMsg(MyMsg);
	}
  else
	{

	FileSeek(iFileHandle,0,0);

	strcpy(MyMsg,"Opened File: ");
	strcat(MyMsg,filename);
	ShowMsg(MyMsg);
	passed = true;

	while (iBytesRead && passed){

	  iBytesRead = FileRead(iFileHandle, &Read_Buffer, 512); // limit to 512 for now
	  if (iBytesRead) {

		AddToBuffer(0x00);
		AddToBuffer((iBytesRead-1) & 0xFF);
		AddToBuffer(((iBytesRead-1)>> 8) & 0xFF);
		passed = SendData(ftHandle);

		ft_res = FT_Write(ftHandle,Read_Buffer,iBytesRead,&numberwritten);

		if(ft_res!= FT_OK) passed = false;
		}
	  }

	FileClose(iFileHandle);

	strcpy(MyMsg,"Closed File: ");
	strcat(MyMsg,filename);
	ShowMsg(MyMsg);

	}

}
//---------------------------------------------------------------------------

void __fastcall TForm1::Button2Click(TObject *Sender)
{
  char baseDriveName[MAXFILE+4];
  char baseDirName[MAXFILE+4];
  char baseFileName[MAXFILE+4];
  char baseFileExt[MAXFILE+4];
  char MyMsg[256];


  if (Form1->OpenDialog1->Execute())
  {
	try
	{
	if (Form1->OpenDialog1->FileName != "")
	  {
	  fnsplit(Form1->OpenDialog1->FileName.t_str(), baseDriveName, baseDirName, baseFileName, baseFileExt);
	  send_file(Form1->OpenDialog1->FileName.t_str());
	  }
	else
	  {
	  Application->MessageBox(L"Error: You must Select a valid filename", L"File Error", IDOK);
	  }
	}
	catch(...)
	{
	  Application->MessageBox(L"Can't perform one of the following file operations: Open, Seek, Read, Close.", L"File Error", IDOK);
	}
  }

  Form1->Update();


}
//---------------------------------------------------------------------------

void __fastcall TForm1::RadioButton7Click(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);
}
//---------------------------------------------------------------------------

void __fastcall TForm1::RadioButton8Click(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);
}
//---------------------------------------------------------------------------

void __fastcall TForm1::RadioButton9Click(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);

}
//---------------------------------------------------------------------------

void __fastcall TForm1::RadioButton10Click(TObject *Sender)
{
  bool passed;
  set_setup_ctrl_byte();
  passed = send_command(CMD_SETUP);

}
//---------------------------------------------------------------------------

void __fastcall TForm1::Button3Click(TObject *Sender)
{

  send_command(CMD_RD_MDM);

}
//---------------------------------------------------------------------------

void __fastcall TForm1::Button4Click(TObject *Sender)
{

  char MyMsg[256];

 strcpy(MyMsg,"This application is used to control the code in a"); ShowMsg(MyMsg);
 strcpy(MyMsg,"Morph-IC II board for testing the FT1248 mode of the "); ShowMsg(MyMsg);
 strcpy(MyMsg,"FT232H chip."); ShowMsg(MyMsg);
 strcpy(MyMsg," "); ShowMsg(MyMsg);
 strcpy(MyMsg,"The code for the Morph-IC-II should be loaded to the FPGA using  "); ShowMsg(MyMsg);
 strcpy(MyMsg,"AlteraLd.exe. The file to use is MorphIC_HS_FT1248.rbf. "); ShowMsg(MyMsg);
 strcpy(MyMsg," "); ShowMsg(MyMsg);
 strcpy(MyMsg,"This program is necessary to set up the mode of the Morph-IC-II or to "); ShowMsg(MyMsg);
 strcpy(MyMsg,"write data to the FT1248. For reads a normal terminal program can be "); ShowMsg(MyMsg);
 strcpy(MyMsg,"used. "); ShowMsg(MyMsg);
 strcpy(MyMsg," "); ShowMsg(MyMsg);
 strcpy(MyMsg,"The required FT1248 mode needs to programmer to the EEPROM using FT_Prog. "); ShowMsg(MyMsg);
 strcpy(MyMsg," "); ShowMsg(MyMsg);
 strcpy(MyMsg,"To opperate correctly the matching FT1248 Mode to the EEPROM needs to selected "); ShowMsg(MyMsg);
 strcpy(MyMsg,"be FT1248 Controller before the Morph-IC-II A port is opened. "); ShowMsg(MyMsg);
 strcpy(MyMsg," "); ShowMsg(MyMsg);

}

//---------------------------------------------------------------------------

void __fastcall TForm1::CheckBox7Click(TObject *Sender)
{

global_data_size_bytes = 0;
global_data_size_megabytes = 0;
show_megabytes = false;
Form1->Edit1->Clear();

}
//---------------------------------------------------------------------------

void __fastcall TForm1::Button5Click(TObject *Sender)
{
  char baseDriveName[MAXFILE+4];
  char baseDirName[MAXFILE+4];
  char baseFileName[MAXFILE+4];
  char baseFileExt[MAXFILE+4];
  char MyMsg[256];


  if (Form1->Button5->Caption =="Rcv File" )
	{


	if (Form1->SaveDialog1->Execute())
	  {
	  try
	  {
	  if (Form1->SaveDialog1->FileName != "")
		{
		fnsplit(Form1->SaveDialog1->FileName.t_str(), baseDriveName, baseDirName, baseFileName, baseFileExt);
    	Form1->Button5->Caption = "Stop Rcv";
		receiving_file = true;
		save_file(Form1->SaveDialog1->FileName.t_str());
		}
	  else
		{
		Application->MessageBox(L"Error: You must Select a valid filename", L"File Error", IDOK);
		}
	  }
	  catch(...)
	  {
	  Application->MessageBox(L"Can't perform one of the following file operations: Open, Seek, Read, Close.", L"File Error", IDOK);
	  }
	}
  }
  else
	{
	receiving_file = false;
	Form1->Button5->Caption = "Rcv File";
	}


  Form1->Update();


}
//---------------------------------------------------------------------------

